#!/usr/bin/env python3

""" terrible script """

__version__ = "0.0.1"
__author__ = "James Hodgkinson"
__copyright__ = "Copyright 2019-, James Hodgkinson"
__license__ = "MIT"
__email__ = "james@terminaloutcomes.com"


if __name__ == "__main__":
    print("Sorry, nothing to see here.")
